API docs for “spamfighter.core.commands.serialize.DateTime”

# Class s.c.c.s.DateTime(datetime.datetime):

Part of spamfighter.core.commands.serialize View Source View In Hierarchy

Наследник datetime.datetime, который требует в конструктор строку в формате ISO 8601 и при вызове str сериализуется также в формат ISO 8601.

Method | __init__ |
Method | __str__ | Undocumented
Static Method | toISO | Undocumented
Static Method | fromISO | Undocumented

def __init__(self, str): (source)

Parameters | str | Строка с датой в формате ISO 8601 (type: `str` )

def __str__(self): (source)
Undocumented
@staticmethod
def toISO(date): (source)
Undocumented
@staticmethod
def fromISO(str): (source)
Undocumented